==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_es.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Tengo la sospecha de que estamos a punto de descubrir algo terrible.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Siempre lo supe: los dioses deben de estar locos.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dios está loco y el mundo entero es su juguete.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Creo que tienes razón.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Me temo que tienes razón.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Si, es sorprendente.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("¿Qué vamos a hacer acerca de eso?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("No podemos dejarlo así. Tenemos que arrestarlos.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("¿Qué tenemos que hacer?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Meterlos en el manico... Quiero decir en las instalaciones de detención de la FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Tienes razón. ¿Nos llevamos a los dos?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Por supuesto. Si dejamos a uno de ellos aquí, cualquier idea loca se le podría ocurrir. El podría tratar de jugar golf, por ejemplo.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difícil con este club. Creo que seríamos felices si consiguiéramos uno. El otro será inofensivo entonces.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bien, ¿Cuál?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("El amarillo.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("El azul.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Ese amarillo.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Ese azul.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Dejaremos esto al jugador.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dejemos esto al jugador.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Mira ese club: algo terrible le ocurrió.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Una cosa quizás lo succionó.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mi madre tenía razón. El exceso de juego es la raiz de toda la maldad.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Eso es verdad. Sería mucho más fácil si esa.paleta de tenis de mesa estuviera en otro lugar.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Por cierto, ¿Notaste que la verdadera bola de golf está en la esquina superior izquierda mientras que esa cosa en la esquina inferior derecha es una bola de cricket?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("¿Hay algún simbolismo escondido?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Quién sabe.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Pensé que eso de ahí arriba era una pelota de tenis de mesa.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Es difícil de saber con esta resolución de pantalla.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("En esta ocasión nuestra meta es sacar a uno de esos dioses.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("¡Yo gané!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("¡Yo comienzo!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("¡Bien!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("¿Jugamos otra vez?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Yo no hago trampa.")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Fué un error, probablemente...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("¡Acertado!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("¡Acertado!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ¡Gané!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("¡Bien!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("¿Lo intentamos de nuevo?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("¡Ya lo has intentado!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("¡Eso ya lo dijiste antes!")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("No puede haber un error en este espacio.")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("¡¡Hiciste trampa!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("¡Ya intenté eso, y tu dijiste \"Errado\"!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_es.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Tengo la sospecha de que estamos a punto de descubrir algo terrible.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Siempre lo supe: los dioses deben de estar locos.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dios está loco y el mundo entero es su juguete.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Creo que tienes razón.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Me temo que tienes razón.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Si, es sorprendente.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("¿Qué vamos a hacer acerca de eso?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("No podemos dejarlo así. Tenemos que arrestarlos.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("¿Qué tenemos que hacer?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Meterlos en el manico... Quiero decir en las instalaciones de detención de la FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Tienes razón. ¿Nos llevamos a los dos?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Por supuesto. Si dejamos a uno de ellos aquí, cualquier idea loca se le podría ocurrir. El podría tratar de jugar golf, por ejemplo.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difícil con este club. Creo que seríamos felices si consiguiéramos uno. El otro será inofensivo entonces.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bien, ¿Cuál?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("El amarillo.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("El azul.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Ese amarillo.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Ese azul.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Dejaremos esto al jugador.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dejemos esto al jugador.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Mira ese club: algo terrible le ocurrió.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Una cosa quizás lo succionó.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mi madre tenía razón. El exceso de juego es la raiz de toda la maldad.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("Eso es verdad. Sería mucho más fácil si esa.paleta de tenis de mesa estuviera en otro lugar.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Por cierto, ¿Notaste que la verdadera bola de golf está en la esquina superior izquierda mientras que esa cosa en la esquina inferior derecha es una bola de cricket?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("¿Hay algún simbolismo escondido?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Quién sabe.")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Pensé que eso de ahí arriba era una pelota de tenis de mesa.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Es difícil de saber con esta resolución de pantalla.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("En esta ocasión nuestra meta es sacar a uno de esos dioses.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("¡Fallado!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("¡Acertado!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("¡Yo gané!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("¡Yo comienzo!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("¡Bien!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("¿Jugamos otra vez?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Yo no hago trampa.")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Fué un error, probablemente...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("¡Errado!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("¡Acertado!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("¡Acertado!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("¡Acertado!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("¡Se hundió!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ha, ha, ha... ¡Gané!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("¡Bien!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("¿Lo intentamos de nuevo?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("¡Ya lo has intentado!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("¡Eso ya lo dijiste antes!")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("No puede haber un error en este espacio.")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("¡¡Hiciste trampa!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("¡Ya intenté eso, y tu dijiste \"Errado\"!")
